@@ -4,11 +4,14 @@ from .wavernn import audio
 from .wavernn import hparams as hp
 import numpy as np
 import torch
+from ..logger import logger
 
 
 class VocoderDataset(Dataset):
     def __init__(self, metadata_fpath: Path, mel_dir: Path, wav_dir: Path):
-        print("Using inputs from:\n\t%s\n\t%s\n\t%s" % (metadata_fpath, mel_dir, wav_dir))
+        logger.info(
+            "Using inputs from:\n\t%s\n\t%s\n\t%s" % (metadata_fpath, mel_dir, wav_dir)
+        )
 
         with metadata_fpath.open("r") as metadata_file:
             metadata = [line.split("|") for line in metadata_file]
@@ -19,7 +22,7 @@ class VocoderDataset(Dataset):
         wav_fpaths = [wav_dir.joinpath(fname) for fname in wav_fnames]
         self.samples_fpaths = list(zip(gta_fpaths, wav_fpaths))
 
-        print("Found %d samples" % len(self.samples_fpaths))
+        logger.info("Found %d samples" % len(self.samples_fpaths))
 
     def __getitem__(self, index):
         mel_path, wav_path = self.samples_fpaths[index]
@@ -61,10 +64,13 @@ def collate_vocoder(batch):
     mel_offsets = [np.random.randint(0, offset) for offset in max_offsets]
     sig_offsets = [(offset + hp.voc_pad) * hp.hop_length for offset in mel_offsets]
 
-    mels = [x[0][:, mel_offsets[i] : mel_offsets[i] + mel_win] for i, x in enumerate(batch)]
+    mels = [
+        x[0][:, mel_offsets[i] : mel_offsets[i] + mel_win] for i, x in enumerate(batch)
+    ]
 
     labels = [
-        x[1][sig_offsets[i] : sig_offsets[i] + hp.voc_seq_len + 1] for i, x in enumerate(batch)
+        x[1][sig_offsets[i] : sig_offsets[i] + hp.voc_seq_len + 1]
+        for i, x in enumerate(batch)
     ]
 
     mels = np.stack(mels).astype(np.float32)
